@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/firehose/Firehose_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/firehose/Firehose_EXPORTS.h>
 
-namespace Aws
-{
-namespace Firehose
-{
-namespace Model
-{
-  enum class Connectivity
-  {
-    NOT_SET,
-    PUBLIC_,
-    PRIVATE_
-  };
+namespace Aws {
+namespace Firehose {
+namespace Model {
+enum class Connectivity { NOT_SET, PUBLIC_, PRIVATE_ };
 
-namespace ConnectivityMapper
-{
+namespace ConnectivityMapper {
 AWS_FIREHOSE_API Connectivity GetConnectivityForName(const Aws::String& name);
 
 AWS_FIREHOSE_API Aws::String GetNameForConnectivity(Connectivity value);
-} // namespace ConnectivityMapper
-} // namespace Model
-} // namespace Firehose
-} // namespace Aws
+}  // namespace ConnectivityMapper
+}  // namespace Model
+}  // namespace Firehose
+}  // namespace Aws
