@@ -4,30 +4,19 @@
  */
 
 #pragma once
-#include <aws/firehose/Firehose_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/firehose/Firehose_EXPORTS.h>
 
-namespace Aws
-{
-namespace Firehose
-{
-namespace Model
-{
-  enum class DeliveryStreamType
-  {
-    NOT_SET,
-    DirectPut,
-    KinesisStreamAsSource,
-    MSKAsSource,
-    DatabaseAsSource
-  };
+namespace Aws {
+namespace Firehose {
+namespace Model {
+enum class DeliveryStreamType { NOT_SET, DirectPut, KinesisStreamAsSource, MSKAsSource, DatabaseAsSource };
 
-namespace DeliveryStreamTypeMapper
-{
+namespace DeliveryStreamTypeMapper {
 AWS_FIREHOSE_API DeliveryStreamType GetDeliveryStreamTypeForName(const Aws::String& name);
 
 AWS_FIREHOSE_API Aws::String GetNameForDeliveryStreamType(DeliveryStreamType value);
-} // namespace DeliveryStreamTypeMapper
-} // namespace Model
-} // namespace Firehose
-} // namespace Aws
+}  // namespace DeliveryStreamTypeMapper
+}  // namespace Model
+}  // namespace Firehose
+}  // namespace Aws
